#
# spec file for package javaparser
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           javaparser
Version:        3.25.10
Release:        1.3
Summary:        Java Parser and Abstract Syntax Tree for Java
License:        Apache-2.0 OR LGPL-3.0-or-later
Group:          Development/Libraries/Java
URL:            https://javaparser.org
Source0:        https://github.com/javaparser/javaparser/archive/%{name}-parent-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mvn(biz.aQute.bnd:bnd-maven-plugin)
BuildRequires:  mvn(com.google.guava:guava)
BuildRequires:  mvn(org.checkerframework:checker-qual)
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(org.codehaus.mojo:javacc-maven-plugin)
BuildRequires:  mvn(org.javassist:javassist)
BuildArch:      noarch

%description
A set of libraries implementing a Java 1.0 - Java 17 Parser with advanced
analysis functionalities.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-parent-%{version}

sed -i 's/\r//' readme.md

# Remove plugins unnecessary for RPM builds
%pom_remove_plugin -r :jacoco-maven-plugin
%pom_remove_plugin :maven-source-plugin

%pom_add_dep org.checkerframework:checker-qual javaparser-symbol-solver-core

# Compatibility alias
%{mvn_alias} :javaparser-core com.google.code.javaparser:javaparser

# Fix javacc plugin name
sed -i \
  -e 's/ph-javacc-maven-plugin/javacc-maven-plugin/' \
  -e 's/com.helger.maven/org.codehaus.mojo/' \
  javaparser-core/pom.xml

# This plugin is not packaged, so use maven-resources-plugin to accomplish the same thing
%pom_remove_plugin :templating-maven-plugin javaparser-core
%pom_xpath_inject "pom:build" "
<resources>
  <resource>
    <directory>src/main/java-templates</directory>
    <filtering>true</filtering>
    <targetPath>\${basedir}/src/main/java</targetPath>
  </resource>
</resources>" javaparser-core

# Missing dep on jbehave for testing
%pom_disable_module javaparser-core-testing
%pom_disable_module javaparser-core-testing-bdd

# Only need to ship the core module
%pom_disable_module javaparser-core-generators
%pom_disable_module javaparser-core-metamodel-generator
%pom_disable_module javaparser-core-serialization

echo "-reproducible: true" >> javaparser-core/bnd.bnd
echo "-noextraheaders: true" >> javaparser-core/bnd.bnd
echo "-snapshot: SNAPSHOT" >> javaparser-core/bnd.bnd

%build
%{mvn_build} -f -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%doc readme.md changelog.md
%license LICENSE LICENSE.APACHE LICENSE.GPL LICENSE.LGPL

%files javadoc -f .mfiles-javadoc
%license LICENSE LICENSE.APACHE LICENSE.GPL LICENSE.LGPL

%changelog
* Sun May  5 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Upgrade to upstream version 3.25.10
  * Fixed
    + Fix issue 4345 Strange error when trying to find erasure of
    generic t… (PR #4362 by @jlerbsc)
    + fix: issue 4358 prevent infinite cycles with static imports
    (PR #4359 by @kdunee)
    + Refactor ResolvedReferenceType#equals (PR #4351 by @freya022)
    + fix: issue 4331 Cannot be 'abstract' and also 'private'. for
    a private method in an interface (PR #4332 by @jlerbsc)
  * Developer Changes
    + chore(deps): bump actions/checkout from 4.1.1 to 4.1.2 (PR
    [#4341] by @dependabot[bot])
* Sat Jan 13 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Upgrade to upstream version 3.25.8
  * Added
    + feat: creates cache statistics and moves Cache interface to
    javaparser-core (PR #4278 by @jlerbsc)
    + feat: Add parseArrayInitializerExpr to JavaParser API (PR
    [#4276] by @iMashtak)
    + feat: A visitor looking for a node by its position in an AST
    (PR #4258 by @jlerbsc)
  * Changed
    + fix: Partial removal of the use of instanceof in favour of
    the use of the API (PR #4280 by @jlerbsc)
    + [GHA] Run on java 18 (PR #4252 by @hazendaz)
  * Fixed
    + fix: issue 4240 Calling resolve on catch block parameter
    throws exception (PR #4279 by @jlerbsc)
    + Fix: issue 4270 Exception when resolving ObjectCreationExpr
    with nested varargs (PR #4273 by @jlerbsc)
    + add Java_18 to yieldSupport (PR #4262 by @Kimmmey)
    + fix: issue #4245 UnsupportedOperationException with
    LexicalPreservingPrinter when removing a sealed modified (PR
    [#4253] by @jlerbsc)
    + [ci] Fix change log released version as 3.25.7 (PR #4251 by
    @hazendaz)
    + Fix: issue 3278 Lazy types cause stack overflow when trying
    to find the least upper bound type (PR #4246 by @jlerbsc)
  * Developer Changes
    + chore(deps): bump com.google.guava:guava from 32.1.3-jre to
    33.0.0-jre (PR #4264 by @dependabot[bot])
  * Uncategorised
    + Revert "Refactoring: Move cache features to javaparser-core"
    (PR #4274 by @jlerbsc)
* Fri Dec 22 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Upgrade to upstream version 3.25.7
  * Added
    + [GHA] Remove old comment that is no longer valid around jdks
    and add jdk 17 (PR #4226 by @hazendaz)
    + Fix: issue 3833 No enum constant
    com.github.javaparser.ParserConfiguration.LanguageLevel.JAVA_18
    (PR #4221 by @jlerbsc)
  * Changed
    + Refactoring: Move cache features to javaparser-core (PR #4238
    by @jlerbsc)
    + Fix: removes reference to coveralls plugin which is not
    useful because codecov is used to track code coverage (PR
    [#4235] by @jlerbsc)
    + Uses jakarta.json api, upgrades jakarta.json-api to the
    latest version & uses new default Eclipse Parsson (PR #4234
    by @jlerbsc)
    + Move mockito to 4.11.0 and handle byte buddy consistently as
    well as properly define its agent in argLine for surefire (PR
    [#4228] by @hazendaz)
    + Cleanup poms, use jakarta provided (javax namespace),
    hamcrest follow up, and switch coveralls plugin - Fixes #4111
    (PR #4225 by @hazendaz)
    + [pom] Switch from hamcrest-library (deprecated) to hamcrest
    (PR #4200 by @hazendaz)
    + Putting code in the .orElse that has a side effect that can
    affect performance (PR #4199 by @jlerbsc)
  * Fixed
    + Fix: issue 3650 unreproducible MAVEN_BUILD_TIMESTAMP (PR
    [#4243] by @jlerbsc)
    + Fix: issue 3972 StackOverflowError when resolving type of
    scope of a MethodCall (PR #4236 by @jlerbsc)
    + [fix] Jdk 18 enum stub was extended off java 16 post
    processor not java17 (PR #4227 by @hazendaz)
    + Fix: issue #4047 Symbol Solver mixes name with type (PR #4206
    by @jlerbsc)
    + Fix grammar (PR #4203 by @mernst)
    + Minor changes : corrupted format, useless cast, javadoc (PR
    [#4198] by @jlerbsc)
  * Developer Changes
    + chore(deps): update actions/setup-java action to v4 (PR #4241
    by @renovate[bot])
    + chore(deps): bump org.codehaus.mojo:build-helper-maven-plugin
    from 3.4.0 to 3.5.0 (PR #4223 by @dependabot[bot])
    + Adds sponsor link to help the project live and grow (PR #4204
    by @jlerbsc)
    + chore(deps): bump org.codehaus.mojo:templating-maven-plugin
    from 1.0.0 to 3.0.0 (PR #4195 by @dependabot[bot])
    + chore(deps): update junit5 monorepo to v5.10.1 (PR #4193 by
    @renovate[bot])
  * Uncategorised
    + Added unit tests for visitors (PR #4239 by @4everTheOne)
    + Unit tests for class GenericListVisitorAdapter (PR #4237 by
    @4everTheOne)
    + Update readme.md (PR #4222 by @jlerbsc)
* Wed Nov 22 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Upgrade to upstream version 3.25.6
  * Changed
    + reformat javaconcept take 2 (PR #4167 by @JimmyGan437)
    + Using JAXP on XMLPrinter implementation (PR #4166 by
    @lcbarcellos)
    + replace deprecated methond calls to their replacements (PR
    [#4157] by @JimmyGan437)
    + feat(#4075): Improve the validation error messages (PR #4116
    by @volodya-lombrozo)
  * Fixed
    + Fix: issue #2751 new HashSet()" != "new HashSet<>() (PR #4183
    by @lcbarcellos)
    + Fixes #2625 Add messages to thrown exceptions (PR #4177 by
    @oannhpham)
    + Fix: issue 4163 Calling
    MethodDeclaration.getDeclarationAsString leads to
    MethodDelaration.getComment returning no comment (PR #4165 by
    @jlerbsc)
    + Fix: issue 3673 isAssignableBy method StackOverflowError (PR
    [#4156] by @jlerbsc)
    + fix: issue 3184 Unable to get the resolved type of class
    ResolvedReferenceType from T (PR #4147 by @jlerbsc)
    + Fix: issue #3269 Test resources containing included
    interfaces do not compile (PR #4139 by @jlerbsc)
    + CalculateResolvedType Type error (PR #4138 by @jlerbsc)
    + Fix: issue #4036 LeastUpperBoundLogic.lub returns null when
    matches ConditionalExpr (PR #4137 by @jlerbsc)
    + Fix: issue #2484 SymbolResolver on MethodCallExpr fails if
    method parameter is of kind Class<? extends y> (PR #4136 by
    @jlerbsc)
  * Developer Changes
    + chore(deps): bump com.google.guava:guava from 32.1.2-jre to
    32.1.3-jre (PR #4154 by @dependabot[bot])
    + chore(deps): update actions/checkout action to v4 (PR #4141
    by @renovate[bot])
* Thu Oct 26 2023 Fridrich Strba <fstrba@suse.com>
- Avoid incompatibilities in jdk 21 by building with release 8
* Mon Sep 11 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible: don't emit timestamp by bnd-maven-plugin
* Sat Sep  9 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Fri Sep  1 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Upgrade to upstream version 3.25.5
  * Added
    + fix: issue 4115 ResolvedUnionType should give access to a
    list of resolved types (PR #4119 by @jlerbsc)
    + Support getting more annotation default values using
    reflection (PR #4103 by @freya022)
  * Changed
    + Minor refactoring: Simplifies how to group deleted tokens by
    extracting a method into an independent class (PR #4134 by
    @jlerbsc)
    + Replace deprecated command with environment file (PR #4122 by
    @70825)
    + Fixes missing named constructor in Modifier.java (PR #4092 by
    @Auties00)
  * Fixed
    + Fix: issue 4133 Top-level class containerType() throws an
    exception instead of Optional.empty() (PR #4135 by @jlerbsc)
    + Fix: apply multiline strings (PR #4130 by @70825)
    + Fix: issue 3976 Issue resolving implicit generic types (PR
    [#4128] by @jlerbsc)
    + Add unit test for PR 4091 Fixed missing permits in pretty
    printer (PR #4126 by @jlerbsc)
    + Fix: issue 4124 UnsupportedOperationException: 'T' is thrown
    in MethodCallExpr resolve (PR #4125 by @jlerbsc)
    + Fix: issue 4051 Switched upperBounds and lowerBounds on
    ResolvedTypeP… (PR #4123 by @jlerbsc)
    + Fix failing test on JDK 17 (PR #4121 by @mahesh-hegde)
    + Fix: issue 3673 isAssignableBy method StackOverflowError (PR
    [#4118] by @jlerbsc)
    + Orphan comment added when using lexical preservation is not
    printed (PR #4114 by @jlerbsc)
    + Fixed missing permits in pretty printer (PR #4091 by
    @Auties00)
  * Developer Changes
    + chore(deps): update actions/checkout action to v3.6.0 (PR
    [#4127] by @renovate[bot])
    + chore(deps): bump com.google.guava:guava from 32.1.1-jre to
    32.1.2-jre (PR #4109 by @dependabot[bot])
  * Uncategorised
    + Fix: issue 4104 LPP doesn't handle new switch entries well
    (PR #4106 by @jlerbsc)
* Fri Jul 14 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Upgrade to upstream version 3.25.4
  * Changed
    + Nested 'if' statements should be simplified (PR #4085 by
    @jlerbsc)
    + BDD tests: migrate to JBehave 5 (PR #4028 by @valfirst)
  * Fixed
    + Fix: issue 4077 After building JavaParser (with tests) on
    MacOS multi… (PR #4086 by @jlerbsc)
    + fix line separators of selected test files (PR #4083 by
    @abego)
    + Fix: issue 3978 typesolver can't parse in parallel (PR #4073
    by @jlerbsc)
    + Fix #4056 isDeclaredInInterface() returns true for fields
    declared inside enumerations contained in an interface (PR
    [#4057] by @Elewyth)
    + Fix: issue 4037 ArrayIndexOutOfBoundsException throws when
    method param is variadic (PR #4046 by @jlerbsc)
    + Fix: issue 4016 Failed to parse variable with name 'sealed'
    or 'permits' (PR #4039 by @jlerbsc)
  * Developer Changes
    + chore(deps): bump guava from 32.1.0-jre to 32.1.1-jre (PR
    [#4089] by @dependabot[bot])
    + chore(deps): bump guava from 32.0.0-jre to 32.1.0-jre (PR
    [#4087] by @dependabot[bot])
    + chore(deps): bump checkstyle from 10.12.0 to 10.12.1 (PR
    [#4084] by @dependabot[bot])
    + chore(deps): bump versions-maven-plugin from 2.15.0 to 2.16.0
    (PR #4055 by @dependabot[bot])
    + chore(deps): bump maven-release-plugin from 3.0.0 to 3.0.1
    (PR #4053 by @dependabot[bot])
    + chore(deps): bump guava from 31.1-jre to 32.0.0-jre (PR #4042
    by @dependabot[bot])
    + chore(deps): bump maven-dependency-plugin from 3.5.0 to 3.6.0
    (PR #4035 by @dependabot[bot])
    + chore(deps): bump maven-checkstyle-plugin from 3.2.2 to 3.3.0
    (PR #4033 by @dependabot[bot])
    + chore(deps): bump maven-scm-plugin from 2.0.0 to 2.0.1 (PR
    [#4031] by @dependabot[bot])
    + chore(deps): bump codecov/codecov-action from 3.1.3 to 3.1.4
    (PR #4030 by @dependabot[bot])
    + chore(deps): bump build-helper-maven-plugin from 3.3.0 to
    3.4.0 (PR #4026 by @dependabot[bot])
    + chore(deps): update dependency maven to v3.9.2 (PR #4024 by
    @renovate[bot])
* Sun May 21 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Upgrade to upstream version 3.25.3
  * Changed
    + Minor simplification of the Difference class (PR #4008 by
    @jlerbsc)
    + Perf: Remove unnecessary methods and quickly return to the
    Range.cont… (PR #3996 by @jlerbsc)
  * Fixed
    + Fix: issue 1843 Problems with hasAnnotation() and
    hasDirectlyAnnotati… (PR #4015 by @jlerbsc)
    + Fix: Issue 3995 resolving a method call with a variadic
    argument of p… (PR #3998 by @jlerbsc)
    + Fix: issue 3983 why FieldDeclaration in an interface calling
    isStatic… (PR #3986 by @jlerbsc)
  * Developer Changes
    + chore(deps): bump checkstyle from 10.9.3 to 10.10.0 (PR #4014
    by @dependabot[bot])
    + chore(deps): update junit5 monorepo to v5.9.3 (PR #4012 by
    @renovate[bot])
    + chore(deps): bump jacoco-maven-plugin from 0.8.9 to 0.8.10
    (PR #4011 by @dependabot[bot])
    + chore(deps-dev): bump okhttp from 4.10.0 to 4.11.0 (PR #4009
    by @dependabot[bot])
    + chore(deps): bump codecov/codecov-action from 3.1.2 to 3.1.3
    (PR #4006 by @dependabot[bot])
    + chore(deps): bump maven-checkstyle-plugin from 3.2.1 to 3.2.2
    (PR #4005 by @dependabot[bot])
    + chore(deps): bump actions/checkout from 3.5.1 to 3.5.2 (PR
    [#3994] by @dependabot[bot])
    + chore(deps): bump actions/checkout from 3.5.0 to 3.5.1 (PR
    [#3992] by @dependabot[bot])
    + chore(deps): bump codecov/codecov-action from 3.1.1 to 3.1.2
    (PR #3988 by @dependabot[bot])
    + chore(deps): bump maven-deploy-plugin from 3.1.0 to 3.1.1 (PR
    [#3985] by @dependabot[bot])
    + chore(deps): bump jacoco-maven-plugin from 0.8.8 to 0.8.9 (PR
    [#3981] by @dependabot[bot])
    + chore(deps): bump checkstyle from 10.9.1 to 10.9.3 (PR #3980
    by @dependabot[bot])
    + chore(deps): bump maven-resources-plugin from 3.3.0 to 3.3.1
    (PR #3979 by @dependabot[bot])
    + chore(deps): bump maven-install-plugin from 3.1.0 to 3.1.1
    (PR #3975 by @dependabot[bot])
    + chore(deps): bump maven-release-plugin from 2.5.3 to 3.0.0
    (PR #3965 by @dependabot[bot])
  * Uncategorised
    + add test for showing interface field shall be static & final
    (PR #3984 by @XenoAmess)
* Sun Apr  2 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Upgrade to upstream version 3.25.2
  * Changed
    + chore(deps): bump maven-scm-plugin from 1.13.0 to 2.0.0 (PR
    [#3961] by @dependabot[bot])
    + chore(deps): bump checkstyle from 10.8.1 to 10.9.1 (PR #3958
    by @dependabot[bot])
    + chore(deps): bump actions/checkout from 3.3.0 to 3.4.0 (PR
    [#3954] by @dependabot[bot])
  * Fixed
    + Fix: issue 3947 MANIFEST.MF points to non-existent URL (PR
    [#3966] by @jlerbsc)
    + Fix: issue 3951 ConfilictingGenericTypesException is thrown
    when an Object type is expected as a parameter and an
    interface is provided as the actual parameter (PR #3963 by
    @jlerbsc)
    + Fix: issue 3949 LexicalPreservingPrinter Ignores Changes to
    LambdaExp… (PR #3959 by @jlerbsc)
    + Fix: Unit test since Return-Type-Substituable is fully
    implemented on reference type (PR #3943 by @jlerbsc)
    + Fix: issue on FunctionalInterfaceLogic but waiting for
    Return-Type-Su… (PR #3941 by @jlerbsc)
    + Suggested fix: hardcoded specific LambdaExpr case in
    LexicalDifferenc… (PR #3938 by @blacelle)
    + Fix TextBlockLiteralExpr in LexicalDifferenceCalculator (PR
    [#3937] by @blacelle)
    + Fix: issue 3919 An array of primitive type cannot be assigned
    to an array of object (PR #3933 by @jlerbsc)
* Wed Mar  8 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Upgrade to upstream version 3.25.1
  * API or Behaviour Change
    + Fix: Issue 3045 Unexpected exception when solving type inside
    an Anonymous class (PR #3896 by @jlerbsc)
  * Added
    + Improved search for functional interfaces (PR #3894 by
    @jlerbsc)
  * Changed
    + chore(deps): bump maven-compiler-plugin from 3.10.1 to 3.11.0
    (PR #3928 by @dependabot[bot])
    + chore(deps): bump checkstyle from 10.7.0 to 10.8.0 (PR #3927
    by @dependabot[bot])
    + chore(deps): bump versions-maven-plugin from 2.14.2 to 2.15.0
    (PR #3914 by @dependabot[bot])
    + chore(deps): bump maven-javadoc-plugin from 3.4.1 to 3.5.0
    (PR #3906 by @dependabot[bot])
    + Refactor: cleanup/refactor code after fixing #3859 (PR #3886
    by @abego)
  * Fixed
    + Fix: issue 3924 Removing ImportDeclaration with Annotated
    package thr… (PR #3926 by @jlerbsc)
    + Fix: issue 3918 JavaParserTypeDeclarationAdapter resolving
    wrong Type via Ancestor (PR #3921 by @jlerbsc)
    + Fix: issue 3919 ResolvedType::isAssignableBy(ResolvedType) is
    wrong f… (PR #3920 by @jlerbsc)
    + Fix: issue 3911 java.lang.UnsupportedOperationException: T[]
    while resolving generic method with type parameter with
    arrays like List<T[]> (PR #3917 by @jlerbsc)
    + Fix: \s escape gives lexical error but should be valid since
    Java 15 (PR #3903 by @jlerbsc)
    + Fix: Issue 3045 Unexpected exception when solving type inside
    an Anonymous class (PR #3896 by @jlerbsc)
    + Fix issue 1883 Finding lambda return type (PR #3890 by
    @jlerbsc)
    + Fix: issue 1815 ArrayIndexOutOfBoundsException when resolving
    lambda parameter. This fix is offered by Blackgen (PR #3888
    by @jlerbsc)
  * Developer Changes
    + chore(deps): bump checkstyle from 10.6.0 to 10.7.0 (PR #3885
    by @dependabot[bot])
- Upgrade to upstream version 3.25.0
  * Added
    + First part of the implementation of least upper bound logic
    (PR #3880 by @jlerbsc)
    + feat: Improved support for calculating the type of an object
    creation… (PR #3877 by @jlerbsc)
    + feat: Implement addRecord & getRecordByName for
    CompilationUnit (PR #3836 by @marcluque)
    + Support Jigsaw requires static (PR #3826 by @jlerbsc)
    + Add toDescriptor to ResolvedMethodDeclaration (PR #3819 by
    @vanHekthor)
    + Refactoring context (WIP) (PR #3792 by @jlerbsc)
    + Refactoring context (WIP) (PR #3782 by @jlerbsc)
    + Refactoring convert to usage (PR #3774 by @jlerbsc)
    + Simplified usage of class AssociableToAST (PR #3063 by
    @4everTheOne)
  * Changed
    + Revert import related checkstyle rule from error to warning
    (PR #3881 by @jlerbsc)
    + Minor refactoring for example to get all parameter types (PR
    [#3879] by @jlerbsc)
    + Add header and footer methods in comments instead of using
    literal st… (PR #3876 by @jlerbsc)
    + In the context of lexical preservation, the CSM token must be
    added m… (PR #3874 by @jlerbsc)
    + Refactoring: remove useless code that is already implemented
    (PR #3869 by @jlerbsc)
    + Memory usage improvement when printing a node from the
    LexicalPreserv… (PR #3858 by @jlerbsc)
    + chore(deps-dev): bump assertj-core from 3.24.1 to 3.24.2 (PR
    [#3852] by @dependabot[bot])
    + chore(deps): bump maven-checkstyle-plugin from 3.2.0 to 3.2.1
    (PR #3846 by @dependabot[bot])
    + chore(deps): bump maven-dependency-plugin from 3.4.0 to 3.5.0
    (PR #3845 by @dependabot[bot])
    + chore(deps): update junit5 monorepo to v5.9.2 (PR #3840 by
    @renovate[bot])
    + Minor refactoring on Difference class (PR #3839 by @jlerbsc)
    + chore(deps-dev): bump assertj-core from 3.23.1 to 3.24.1 (PR
    [#3837] by @dependabot[bot])
    + chore(deps): bump actions/checkout from 3.2.0 to 3.3.0 (PR
    [#3834] by @dependabot[bot])
    + chore(deps): bump checkstyle from 10.5.0 to 10.6.0 (PR #3829
    by @dependabot[bot])
  * Fixed
    + Fix: Method hasScope must return true on
    NodeWithOptionalScope and No… (PR #3875 by @jlerbsc)
    + fix #3859 UnsupportedOperationException when trying to
    resolve a type… (PR #3873 by @abego)
    + Fix: issue 3866 Symbol solver is unable to resolve inner
    classes of ancestors when they are prefixed with a subclass
    (PR #3868 by @jlerbsc)
    + Fix: issue 3703 Allow removing empty parentheses after
    removing all pairs from an annotation (PR #3865 by @jlerbsc)
    + Fix: One must be able to know if any resolved type is a boxed
    primiti… (PR #3864 by @jlerbsc)
    + Fix: Issue 2374 Comments of added Nodes are ignored in
    LexicalPreserv… (PR #3856 by @jlerbsc)
    + Checkstyle for unused import (PR #3841 by @4everTheOne)
    + Update bnd file (PR #3783 by @jlerbsc)
  * Developer Changes
    + Update javaparser copyright headers (PR #3862 by @jlerbsc)
  * Uncategorised
    + Add test case to verify range calculation on ArrayType (PR
    [#3828] by @jlerbsc)
    + Add test case to verify that LexicalPreservation supports
    TextBlock (PR #3827 by @jlerbsc)
    + Refactoring: Removing useless method convertToUsage in
    JavaParserFacade (PR #3780 by @jlerbsc)
* Sat Jan 28 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Upgrade to upstream version 3.24.10
  * Added
    + Add a method in LexicalPreservingPrinter to know if LPP is
    available/activated on the specified node (PR #3823 by
    @jlerbsc)
    + Handle nested records (PR #3814 by @mernst)
    + Source printer import ordering strategy (PR #3807 by
    @4everTheOne)
  * Changed
    + chore(deps): bump versions-maven-plugin from 2.14.1 to 2.14.2
    (PR #3817 by @dependabot[bot])
    + Enabled import validation (PR #3812 by @4everTheOne)
    + Part 5 | Import organization (PR #3805 by @4everTheOne)
    + Part 4 | Import organization (PR #3804 by @4everTheOne)
    + Part 3 | Import organization (PR #3803 by @4everTheOne)
    + Part 2 | Import organization (PR #3802 by @4everTheOne)
    + Part 1 | Import organization (PR #3801 by @4everTheOne)
    + Checkstyle configuration tweaks (PR #3799 by @4everTheOne)
    + chore(deps): bump versions-maven-plugin from 2.13.0 to 2.14.1
    (PR #3797 by @dependabot[bot])
    + chore(deps): bump actions/checkout from 3.1.0 to 3.2.0 (PR
    [#3789] by @dependabot[bot])
    + chore(deps): bump checkstyle from 8.45.1 to 10.5.0 (PR #3788
    by @dependabot[bot])
  * Fixed
    + explicit use asString for performance (PR #3821 by @dencat)
    + Fix: issue #3818 Wrong range calculation on ArrayType with
    multiple d… (PR #3820 by @jlerbsc)
    + Fix: Lexical Preserving Fails To Remove Comment (PR #3810 by
    @jlerbsc)
  * Developer Changes
    + chore(deps): bump versions-maven-plugin from 2.13.0 to 2.14.0
    (PR #3794 by @dependabot[bot])
    + Basic CheckStyle validation (PR #3781 by @4everTheOne)
  * Uncategorised
    + Fix: 3412 Remove walkmod again (PR #3806 by @jlerbsc)
* Mon Dec 12 2022 Anton Shvetz <shvetz.anton@gmail.com>
- Upgrade to upstream version 3.24.9
  * Highlights
    + Remove "executable" bit from code files (PR #3755 by @icmdaf)
  * Added
    + Created TypeSolverBuilder (PR #3421 by @4everTheOne)
  * Changed
    + Changing, in test classes, the initialization of the lexical
    preserva… (PR #3779 by @jlerbsc)
    + chore(deps): bump maven-dependency-plugin from 3.3.0 to 3.4.0
    (PR #3770 by @dependabot[bot])
    + chore(deps): bump maven-install-plugin from 3.0.1 to 3.1.0
    (PR #3756 by @dependabot[bot])
  * Fixed
    + Fix: #3195 Resolved methods in outer classes not inferred
    correcly (PR #3778 by @jlerbsc)
    + Fix: #3681 LineComment alwaysing trimming content (PR #3777
    by @jlerbsc)
    + Fix: #3773 Replacing nodes causes error in lexical preserving
    printer… (PR #3776 by @jlerbsc)
    + Fix: #2517 Modifying some nodes with the lexicalPreservation
    enabled … (PR #3775 by @jlerbsc)
    + Fix: #3725 JavaParserFacade var type in for-each loop cannot
    be resolved (PR #3768 by @abego)
    + Fix: #3216 LexicalPreservingPrinter add Wrong indentation
    when removing comments (PR #3766 by @jlerbsc)
    + Fix: #3472 Line comment removal causes IllegalStateException
    with LexicalPreservingPrinter (PR #3765 by @jlerbsc)
    + Fix: #3441 LexicalPreservingPrinter prints wrong output with
    line com… (PR #3764 by @jlerbsc)
    + Fix: #2137 ClassOrInterfaceDeclaration addMember using index
    (PR #3763 by @jlerbsc)
    + Fix: #3761 Lexical preserving corrupts source when adding a
    modifier in first position (PR #3762 by @jlerbsc)
    + Fix: #3693 Removing modifiers from method declaration results
    in loss… (PR #3760 by @jlerbsc)
    + Fix: #3750 Lexical preserving corrupts source (PR #3759 by
    @jlerbsc)
    + Fix: Fix the indentation generated by the
    LexicalPreservingPrinter wh… (PR #3758 by @jlerbsc)
  * Security
    + Remove "executable" bit from code files (PR #3755 by @icmdaf)
- Add build dependency on mvn(org.checkerframework:checker-qual)
* Sun Nov 27 2022 Anton Shvetz <shvetz.anton@gmail.com>
- Upgrade to upstream version 3.24.8
  * Added
    + [Fixes #3099] Added ability to solve type with a list of
    expected type arguments
    + [Suggestion] NonNull generator for parameters
  * Changed
    + Updated workflow to only run one job per PR
    + Remove or comment system.out.println statement in unit tests
    + Added Optional method in SymbolReference
    + Centralized management of symbol solver exceptions to prevent
    exception type Erasion
  * Fixed
    + Fix issue #1827 Issue resolving a constructor of a class
    using generics
    + Fix issue #3728 ParseProblemException
    + Updated Badge for Build and Coverage
    + Position
    + Fix part of issue #3721 UnsupportedOperationException while
    trying to modify the type of a variable
    + Implemented isReferenceType in ResolvedTypeDeclaration and
    isTypeParameter in ResolvedTypeParameterDeclaration
  * Developer Changes
    + chore(deps): bump versions-maven-plugin from 2.12.0 to 2.13.0
    + Fix maven wrapper not found in generator scripts
    + chore(deps): bump actions/checkout from 3.0.2 to 3.1.0
  * Uncategorised
    + Change issue 1945 test to paramaterized
    + More unit tests for JavaToken and CodeGenerationUtils
- Upgrade to upstream version 3.24.7
  * Highlights
    + Issue #3415
  * Changed
    + Refactoring - use of existing methods
    + Refactoring adding convenient methods to know if a
    DifferenceElement is added, removed or kept
  * Deprecated
    + Issue #3415
  * Fixed
    + Fix for ReflectionAnnotationDeclaration getClassName()
    + Fix some yield expressions not recognized
    + Accept final in instanceof pattern
    + [Fix] Avoid test failure due to line separator differences on
    windows host
    + Fix issue #3700 Removing last statement with
    LexicalPreservingPrinter results in loss of indendation
    + Fix issue #3678 Function accepts a configuration but it does
    not do anything
- Upgrade to upstream version 3.24.3
  * API or Behaviour Change
    + Issue #3405 thread safety of pre/postprocessors (incl.
    breaking change to Processor with pre/post processor
    methods).
  * Changed
    + Minor refactoring to manage check in range and use hasRange
    method in class CommentsInserter
    + Renaming PACKAGE_PRIVATE to NONE (this refers to the
    discussion in the issue #2242)
  * Fixed
    + Fix documentation of JAVA_17
    + Fix issue 3631 NameExpr.resolve() does not take end of inner
    block scopes into account
    + Fix issue #3588 Modifier is removed when removing an
    annotation
    + Fix lambda generic types that are always resolved to the
    first type param
    + Fix issue #3489 SourceRoot.tryToParse() fails if the root
    path ends with a directory that is not a java identifier
    + Default pretty printer should print inner-class receiver
    parameters on constructors
    + Issue #3405 thread safety of pre/postprocessors (incl.
    breaking change to Processor with pre/post processor
    methods).
  * Developer Changes
    + chore(deps): update actions/checkout action to v3.0.1
    + official Apache Maven wrapper
    + chore(deps): update codecov/codecov-action action to v3
    + chore(deps): update dependency org.jacoco:jacoco-maven-plugin
    to v0.8.8
    + chore(deps): update dependency
    org.apache.maven.plugins:maven-clean-plugin to v3.2.0
    + chore(deps): update dependency
    org.apache.maven.plugins:maven-surefire-plugin to v3.0.0-m6
- Re-enable modules:
  javaparser-symbol-solver-{core,logic,model,testing}
- Add build dependency on mvn(org.javassist:javassist)
- Update summary and description
* Mon May 23 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.24.2
  * Fixes:
    + Adding constructor descriptor
    + Fix issue #3491  Method has a multidimensional arrays argument
    in jar file. when call the method throw
    UnsolvedSymbolException
    + Fix issue #3218 GetSourceRoots() does not return all source
    roots
    + Bug in ArrayCreationExpr constructors
    + Fix issue 3440 Removing a node with LexicalPreservingPrinter
    causes UnsupportedOperationException
    + Improve unit test for BlockStmtContextResolutionTest
    + Improve Conditional Operator resolution [JLS 15.25]
    + Fix issue #3526 Variable or FieldDeclaration is not resolved
    correctly when another variable with the same name is
    declared in the same block
* Thu Mar 10 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to the latest version 3.24.0
  * A long list of fixes is to be found at https://github.com/
    /javaparser/javaparser/blob/master/changelog.md
  * Upgrade needed to be able to upgrade jctools and make them
    not depend hard on Java 8
* Tue Oct  1 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of javaparser 3.3.5
